@@ -10,44 +10,28 @@
  *
  *	Sverre H. Huseby <sverrehu@online.no>
  *
- *	Portions Copyright (c) 1996-2003, PostgreSQL Global Development Group
+ *	Portions Copyright (c) 1996-2005, PostgreSQL Global Development Group
  *	Portions Copyright (c) 1994, Regents of the University of California
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql-server/src/backend/libpq/md5.c,v 1.21 2003/08/04 02:39:59 momjian Exp $
+ *	  $PostgreSQL: pgsql/src/backend/libpq/md5.c,v 1.27 2004/12/31 21:59:50 pgsql Exp $
  */
 
 
-/*
- *	NOTE:
- *
- *	There are two copies of this file, one in backend/libpq and another
- *	in interfaces/odbc.  They should be identical.	This is done so ODBC
- *	can be compiled stand-alone.
- */
-
-#if ! defined(MD5_ODBC) && ! defined(FRONTEND)
+#if ! defined(FRONTEND)
 #include "postgres.h"
 #include "libpq/crypt.h"
 #endif
 
 #ifdef FRONTEND
 #include "postgres_fe.h"
-#ifndef WIN32
 #include "libpq/crypt.h"
-#endif   /* WIN32 */
-#endif   /* FRONTEND */
 
-#ifdef MD5_ODBC
-#include "md5.h"
-#endif
-
-#ifdef FRONTEND
 #undef palloc
 #define palloc malloc
 #undef pfree
 #define pfree free
-#endif
+#endif   /* FRONTEND */
 
 
 /*
@@ -271,7 +255,7 @@ calculateDigestFromBuffer(uint8 *b, uint32 len, uint8 sum[16])
 static void
 bytesToHex(uint8 b[16], char *s)
 {
-	static char *hex = "0123456789abcdef";
+	static const char *hex = "0123456789abcdef";
 	int			q,
 				w;
 
