@@ -8,7 +8,7 @@
  *
  *
  * IDENTIFICATION
- *	  $PostgreSQL: pgsql/src/backend/utils/adt/varlena.c,v 1.118 2004/12/31 22:01:22 pgsql Exp $
+ *	  $PostgreSQL: pgsql/src/backend/utils/adt/varlena.c,v 1.118.4.1 2005/12/22 22:50:14 tgl Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -879,6 +879,15 @@ varstr_cmp(char *arg1, int len1, char *arg2, int len2)
 
 		result = strcoll(a1p, a2p);
 
+		/*
+		 * In some locales strcoll() can claim that nonidentical strings are
+		 * equal.  Believing that would be bad news for a number of reasons,
+		 * so we follow Perl's lead and sort "equal" strings according to
+		 * strcmp().
+		 */
+		if (result == 0)
+			result = strcmp(a1p, a2p);
+
 		if (len1 >= STACKBUFLEN)
 			pfree(a1p);
 		if (len2 >= STACKBUFLEN)
@@ -931,11 +940,15 @@ texteq(PG_FUNCTION_ARGS)
 	text	   *arg2 = PG_GETARG_TEXT_P(1);
 	bool		result;
 
-	/* fast path for different-length inputs */
+	/*
+	 * Since we only care about equality or not-equality, we can avoid all
+	 * the expense of strcoll() here, and just do bitwise comparison.
+	 */
 	if (VARSIZE(arg1) != VARSIZE(arg2))
 		result = false;
 	else
-		result = (text_cmp(arg1, arg2) == 0);
+		result = (strncmp(VARDATA(arg1), VARDATA(arg2),
+						  VARSIZE(arg1) - VARHDRSZ) == 0);
 
 	PG_FREE_IF_COPY(arg1, 0);
 	PG_FREE_IF_COPY(arg2, 1);
@@ -950,11 +963,15 @@ textne(PG_FUNCTION_ARGS)
 	text	   *arg2 = PG_GETARG_TEXT_P(1);
 	bool		result;
 
-	/* fast path for different-length inputs */
+	/*
+	 * Since we only care about equality or not-equality, we can avoid all
+	 * the expense of strcoll() here, and just do bitwise comparison.
+	 */
 	if (VARSIZE(arg1) != VARSIZE(arg2))
 		result = true;
 	else
-		result = (text_cmp(arg1, arg2) != 0);
+		result = (strncmp(VARDATA(arg1), VARDATA(arg2),
+						  VARSIZE(arg1) - VARHDRSZ) != 0);
 
 	PG_FREE_IF_COPY(arg1, 0);
 	PG_FREE_IF_COPY(arg2, 1);
